import cloneDeep from 'lodash/cloneDeep';
import { freezeSys, toPlainObject } from 'contentful-sdk-core';
import enhanceWithMethods from '../enhance-with-methods'; // eslint-disable-next-line
// @ts-ignore

import createOrganizationApi from '../create-organization-api';

/**
 * This method creates the API for the given organization with all the methods for
 * reading and creating other entities. It also passes down a clone of the
 * http client with an organization id, so the base path for requests now has the
 * organization id already set.
 * @private
 * @param http - HTTP client instance
 * @param data - API response for an Organization
 * @return {Organization}
 */
export function wrapOrganization(http, data) {
  var org = toPlainObject(cloneDeep(data));
  var baseURL = (http.defaults.baseURL || '').replace('/spaces/', '/organizations/') + org.sys.id + '/'; // @ts-expect-error

  var orgScopedHttpClient = http.cloneWithNewParams({
    baseURL: baseURL
  });
  var orgApi = createOrganizationApi({
    http: orgScopedHttpClient
  });
  var enhancedOrganization = enhanceWithMethods(org, orgApi);
  return freezeSys(enhancedOrganization);
}
/**
 * This method normalizes each organization in a collection.
 * @private
 * @param http - HTTP client instance
 * @param data - Raw organization collection data
 * @return {OrganizationCollection} Normalized organization collection data
 */

export function wrapOrganizationCollection(http, data) {
  var organizations = toPlainObject(cloneDeep(data));
  organizations.items = organizations.items.map(function (entity) {
    return wrapOrganization(http, entity);
  });
  return freezeSys(organizations);
}