import cloneDeep from 'lodash/cloneDeep';
import { freezeSys, toPlainObject } from 'contentful-sdk-core';
import enhanceWithMethods from '../enhance-with-methods';
import { createUpdateEntity, createDeleteEntity } from '../instance-actions';

function createRoleApi(http) {
  return {
    update: createUpdateEntity({
      http: http,
      entityPath: 'roles',
      wrapperMethod: wrapRole
    }),
    "delete": createDeleteEntity({
      http: http,
      entityPath: 'roles'
    })
  };
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw role data
 * @return Wrapped role data
 */


export function wrapRole(http, data) {
  var role = toPlainObject(cloneDeep(data));
  enhanceWithMethods(role, createRoleApi(http));
  return freezeSys(role);
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw role collection data
 * @return Wrapped role collection data
 */

export function wrapRoleCollection(http, data) {
  var roles = toPlainObject(cloneDeep(data));
  roles.items = roles.items.map(function (entity) {
    return wrapRole(http, entity);
  });
  return freezeSys(roles);
}