import cloneDeep from 'lodash/cloneDeep';
import { freezeSys, toPlainObject } from 'contentful-sdk-core';
import enhanceWithMethods from '../enhance-with-methods';
import { createUpdateEntity, createDeleteEntity } from '../instance-actions';

function createSpaceMembershipApi(http) {
  return {
    update: createUpdateEntity({
      http: http,
      entityPath: 'space_memberships',
      wrapperMethod: wrapSpaceMembership
    }),
    "delete": createDeleteEntity({
      http: http,
      entityPath: 'space_memberships'
    })
  };
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw space membership data
 * @return Wrapped space membership data
 */


export function wrapSpaceMembership(http, data) {
  var spaceMembership = toPlainObject(cloneDeep(data));
  enhanceWithMethods(spaceMembership, createSpaceMembershipApi(http));
  return freezeSys(spaceMembership);
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw space membership collection data
 * @return Wrapped space membership collection data
 */

export function wrapSpaceMembershipCollection(http, data) {
  var spaceMemberships = toPlainObject(cloneDeep(data));
  spaceMemberships.items = spaceMemberships.items.map(function (entity) {
    return wrapSpaceMembership(http, entity);
  });
  return freezeSys(spaceMemberships);
}