import cloneDeep from 'lodash/cloneDeep';
import { freezeSys, toPlainObject } from 'contentful-sdk-core';
import enhanceWithMethods from '../enhance-with-methods';
import errorHandler from '../error-handler';

function createTeamMembershipApi(http) {
  return {
    update: function update() {
      var raw = this.toPlainObject();
      var teamId = raw.sys.team.sys.id;
      return http.put('teams/' + teamId + '/team_memberships/' + this.sys.id, raw, {
        headers: {
          'X-Contentful-Version': this.sys.version || 0
        }
      }).then(function (response) {
        return wrapTeamMembership(http, response.data);
      }, errorHandler);
    },
    "delete": function _delete() {
      var raw = this.toPlainObject();
      var teamId = raw.sys.team.sys.id;
      return http["delete"]('teams/' + teamId + '/team_memberships/' + this.sys.id).then(function () {// do nothing
      }, errorHandler);
    }
  };
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw team membership data
 * @return Wrapped team membership data
 */


export function wrapTeamMembership(http, data) {
  var teamMembership = toPlainObject(cloneDeep(data));
  enhanceWithMethods(teamMembership, createTeamMembershipApi(http));
  return freezeSys(teamMembership);
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw team membership collection data
 * @return Wrapped team membership collection data
 */

export function wrapTeamMembershipCollection(http, data) {
  var teamMemberships = toPlainObject(cloneDeep(data));
  teamMemberships.items = teamMemberships.items.map(function (entity) {
    return wrapTeamMembership(http, entity);
  });
  return freezeSys(teamMemberships);
}