import cloneDeep from 'lodash/cloneDeep';
import { freezeSys, toPlainObject } from 'contentful-sdk-core';
import enhanceWithMethods from '../enhance-with-methods';
import { createDeleteEntity, createUpdateEntity } from '../instance-actions';
var entityPath = 'teams';

function createTeamApi(http) {
  return {
    update: createUpdateEntity({
      http: http,
      entityPath: entityPath,
      wrapperMethod: wrapTeam
    }),
    "delete": createDeleteEntity({
      http: http,
      entityPath: entityPath
    })
  };
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw team data
 * @return Wrapped team data
 */


export function wrapTeam(http, data) {
  var team = toPlainObject(cloneDeep(data));
  enhanceWithMethods(team, createTeamApi(http));
  return freezeSys(team);
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw team collection data
 * @return Wrapped team collection data
 */

export function wrapTeamCollection(http, data) {
  var teams = toPlainObject(cloneDeep(data));
  teams.items = teams.items.map(function (entity) {
    return wrapTeam(http, entity);
  });
  return freezeSys(teams);
}