import cloneDeep from 'lodash/cloneDeep';
import { freezeSys, toPlainObject } from 'contentful-sdk-core';
import enhanceWithMethods from '../enhance-with-methods';
import { createUpdateEntity, createDeleteEntity } from '../instance-actions';

function createUiExtensionApi(http) {
  return {
    update: createUpdateEntity({
      http: http,
      entityPath: 'extensions',
      wrapperMethod: wrapUiExtension
    }),
    "delete": createDeleteEntity({
      http: http,
      entityPath: 'extensions'
    })
  };
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw UI Extension data
 * @return Wrapped UI Extension data
 */


export function wrapUiExtension(http, data) {
  var uiExtension = toPlainObject(cloneDeep(data));
  enhanceWithMethods(uiExtension, createUiExtensionApi(http));
  return freezeSys(uiExtension);
}
/**
 * @private
 * @param http - HTTP client instance
 * @param data - Raw UI Extension collection data
 * @return Wrapped UI Extension collection data
 */

export function wrapUiExtensionCollection(http, data) {
  var uiExtensions = toPlainObject(cloneDeep(data));
  uiExtensions.items = uiExtensions.items.map(function (entity) {
    return wrapUiExtension(http, entity);
  });
  return freezeSys(uiExtensions);
}