function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cloneDeep from 'lodash/cloneDeep';
import errorHandler from '../error-handler';

function getBaseUrl(http) {
  var _http$defaults$baseUR;

  return (_http$defaults$baseUR = http.defaults.baseURL) === null || _http$defaults$baseUR === void 0 ? void 0 : _http$defaults$baseUR.split('/spaces')[0];
}

function normalizeSelect(query) {
  if (query && query.select && !/sys/i.test(query.select)) {
    return _objectSpread(_objectSpread({}, query), {}, {
      select: query.select + ',sys'
    });
  }

  return query;
}

function _get(http, url, config) {
  return http.get(url, _objectSpread({
    baseURL: getBaseUrl(http)
  }, config)).then(function (response) {
    return response.data;
  }, errorHandler);
}

function post(http, url, payload, config) {
  return http.post(url, payload, _objectSpread({
    baseURL: getBaseUrl(http)
  }, config)).then(function (response) {
    return response.data;
  }, errorHandler);
}

function put(http, url, payload, config) {
  return http.put(url, payload, _objectSpread({
    baseURL: getBaseUrl(http)
  }, config)).then(function (response) {
    return response.data;
  }, errorHandler);
}

function del(http, url, config) {
  return http["delete"](url, _objectSpread({
    baseURL: getBaseUrl(http)
  }, config)).then(function (response) {
    return response.data;
  }, errorHandler);
}

export var raw = {
  get: _get,
  post: post,
  put: put,
  "delete": del
};
/**
 * Space
 */

export var space = {
  get: function get(http, params) {
    return _get(http, "/spaces/".concat(params.spaceId));
  },
  update: function update(http, params, raw) {
    var _raw$sys$version;

    var data = cloneDeep(raw);
    delete data.sys;
    return put(http, "/spaces/".concat(params.spaceId), data, {
      headers: {
        'X-Contentful-Version': (_raw$sys$version = raw.sys.version) !== null && _raw$sys$version !== void 0 ? _raw$sys$version : 0
      }
    });
  },
  "delete": function _delete(http, params) {
    return del(http, "/spaces/".concat(params.spaceId));
  }
};

/**
 * Environment
 */
export var environment = {
  get: function get(http, params) {
    return _get(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId));
  },
  update: function update(http, params, raw) {
    var _raw$sys$version2;

    var data = cloneDeep(raw);
    delete data.sys;
    return put(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId), data, {
      headers: {
        'X-Contentful-Version': (_raw$sys$version2 = raw.sys.version) !== null && _raw$sys$version2 !== void 0 ? _raw$sys$version2 : 0
      }
    });
  }
};
/**
 * Content type
 */

export var contentType = {
  getMany: function getMany(http, params) {
    return _get(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/content_types"), {
      params: params.query
    });
  }
};
/**
 * User
 */

export var user = {
  getManyForSpace: function getManyForSpace(http, params) {
    return _get(http, "/spaces/".concat(params.spaceId, "/users"), {
      params: params.query
    });
  }
};

/**
 * Entry
 */
export var entry = {
  get: function get(http, params) {
    return _get(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries/").concat(params.entryId), {
      params: normalizeSelect(params.query)
    });
  },
  getMany: function getMany(http, params) {
    return _get(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries"), {
      params: normalizeSelect(params.query)
    });
  },
  update: function update(http, params, raw) {
    var _raw$sys$version3;

    var data = cloneDeep(raw);
    delete data.sys;
    return put(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries/").concat(params.entryId), data, {
      headers: {
        'X-Contentful-Version': (_raw$sys$version3 = raw.sys.version) !== null && _raw$sys$version3 !== void 0 ? _raw$sys$version3 : 0
      }
    });
  },
  "delete": function _delete(http, params) {
    return del(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries/").concat(params.entryId));
  },
  publish: function publish(http, params, raw) {
    var _raw$sys$version4;

    return put(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries/").concat(params.entryId, "/published"), null, {
      headers: {
        'X-Contentful-Version': (_raw$sys$version4 = raw.sys.version) !== null && _raw$sys$version4 !== void 0 ? _raw$sys$version4 : 0
      }
    });
  },
  unpublish: function unpublish(http, params) {
    return del(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries/").concat(params.entryId, "/published"));
  },
  archive: function archive(http, params) {
    return put(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries/").concat(params.entryId, "/archived"));
  },
  unarchive: function unarchive(http, params) {
    return del(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries/").concat(params.entryId, "/archived"));
  },
  create: function create(http, params, raw) {
    var data = cloneDeep(raw);
    return post(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries"), data, {
      headers: {
        'X-Contentful-Content-Type': params.contentTypeId
      }
    });
  },
  createWithId: function createWithId(http, params, raw) {
    var data = cloneDeep(raw);
    return put(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/entries/").concat(params.entryId), data, {
      headers: {
        'X-Contentful-Content-Type': params.contentTypeId
      }
    });
  }
};
/**
 * Locale
 */

export var locale = {
  getMany: function getMany(http, params) {
    return _get(http, "/spaces/".concat(params.spaceId, "/environments/").concat(params.environmentId, "/locales"), {
      params: normalizeSelect(params.query)
    });
  }
};